==> haskell-doctest-driver-gen-0.3.0.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-driver-gen
version:              0.3.0.5
visibility:           public
id:                   doctest-driver-gen-0.3.0.5-AzvB77sRhpCJXmVZokCODs
key:                  doctest-driver-gen-0.3.0.5-AzvB77sRhpCJXmVZokCODs
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2021
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  fdcb2a46bb9b63fdd27181fef8f3dd6f
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/doctest-driver-gen-0.3.0.5

hs-libraries:         HSdoctest-driver-gen-0.3.0.5-AzvB77sRhpCJXmVZokCODs
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-driver-gen-0.3.0.5-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-driver-gen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-driver-gen
version:              0.3.0.5
visibility:           public
id:                   doctest-driver-gen-0.3.0.5-HbMd4TKPNZOHMkRYnKH6IP
key:                  doctest-driver-gen-0.3.0.5-HbMd4TKPNZOHMkRYnKH6IP
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2021
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  92955b6ddc7b5e49944f83b000c04c55
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-driver-gen-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/doctest-driver-gen-0.3.0.5

hs-libraries:         HSdoctest-driver-gen-0.3.0.5-HbMd4TKPNZOHMkRYnKH6IP
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
